Set the current appendix letter
set_appendix.RdSets the current appendix context for automatic figure and table numbering.
This function stores the appendix letter and automatically configures both
figure and table numbering. For most users, new_appendix() is preferred
as it auto-increments. Use this function when you need to explicitly set
a specific appendix letter.